@@ -5,14 +5,15 @@
 
     Additional docutils nodes.
 
-    :copyright: Copyright 2007-2016 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
-import warnings
-
 from docutils import nodes
-from sphinx.deprecation import RemovedInSphinx16Warning
+
+if False:
+    # For type annotation
+    from typing import List, Sequence  # NOQA
 
 
 class translatable(object):
@@ -30,14 +31,17 @@ class translatable(object):
     """
 
     def preserve_original_messages(self):
+        # type: () -> None
         """Preserve original translatable messages."""
         raise NotImplementedError
 
     def apply_translated_message(self, original_message, translated_message):
+        # type: (unicode, unicode) -> None
         """Apply translated message."""
         raise NotImplementedError
 
     def extract_original_messages(self):
+        # type: () -> Sequence[unicode]
         """Extract translation messages.
 
         :returns: list of extracted messages or messages generator
@@ -45,18 +49,26 @@ class translatable(object):
         raise NotImplementedError
 
 
+class not_smartquotable(object):
+    """A node which does not support smart-quotes."""
+    support_smartquotes = False
+
+
 class toctree(nodes.General, nodes.Element, translatable):
     """Node for inserting a "TOC tree"."""
 
     def preserve_original_messages(self):
-        if 'caption' in self:
+        # type: () -> None
+        if self.get('caption'):
             self['rawcaption'] = self['caption']
 
     def apply_translated_message(self, original_message, translated_message):
+        # type: (unicode, unicode) -> None
         if self.get('rawcaption') == original_message:
             self['caption'] = translated_message
 
     def extract_original_messages(self):
+        # type: () -> List[unicode]
         if 'rawcaption' in self:
             return [self['rawcaption']]
         else:
@@ -84,7 +96,7 @@ class desc_signature(nodes.Part, nodes.Inline, nodes.TextElement):
     """
 
 
-class desc_signature_line(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_signature_line(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for a line in a multi-line object signatures.
 
     It should only be used in a ``desc_signature`` with ``is_multiline`` set.
@@ -94,7 +106,7 @@ class desc_signature_line(nodes.Part, nodes.Inline, nodes.TextElement):
 
 # nodes to use within a desc_signature or desc_signature_line
 
-class desc_addname(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_addname(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for additional name parts (module name, class name)."""
 
 
@@ -102,38 +114,40 @@ class desc_addname(nodes.Part, nodes.Inline, nodes.TextElement):
 desc_classname = desc_addname
 
 
-class desc_type(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_type(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for return types or object type names."""
 
 
 class desc_returns(desc_type):
     """Node for a "returns" annotation (a la -> in Python)."""
     def astext(self):
+        # type: () -> unicode
         return ' -> ' + nodes.TextElement.astext(self)
 
 
-class desc_name(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_name(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for the main object name."""
 
 
-class desc_parameterlist(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_parameterlist(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for a general parameter list."""
     child_text_separator = ', '
 
 
-class desc_parameter(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_parameter(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for a single parameter."""
 
 
-class desc_optional(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_optional(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for marking optional parts of the parameter list."""
     child_text_separator = ', '
 
     def astext(self):
+        # type: () -> unicode
         return '[' + nodes.TextElement.astext(self) + ']'
 
 
-class desc_annotation(nodes.Part, nodes.Inline, nodes.TextElement):
+class desc_annotation(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for signature annotations (not Python 3-style annotations)."""
 
 
@@ -165,7 +179,7 @@ class productionlist(nodes.Admonition, nodes.Element):
     """
 
 
-class production(nodes.Part, nodes.Inline, nodes.TextElement):
+class production(nodes.Part, nodes.Inline, nodes.FixedTextElement):
     """Node for a single grammar production rule."""
 
 
@@ -257,13 +271,13 @@ class download_reference(nodes.reference):
     """Node for download references, similar to pending_xref."""
 
 
-class literal_emphasis(nodes.emphasis):
+class literal_emphasis(nodes.emphasis, not_smartquotable):
     """Node that behaves like `emphasis`, but further text processors are not
     applied (e.g. smartypants for HTML output).
     """
 
 
-class literal_strong(nodes.strong):
+class literal_strong(nodes.strong, not_smartquotable):
     """Node that behaves like `strong`, but further text processors are not
     applied (e.g. smartypants for HTML output).
     """
@@ -273,20 +287,7 @@ class abbreviation(nodes.Inline, nodes.TextElement):
     """Node for abbreviations with explanations."""
 
 
-class termsep(nodes.Structural, nodes.Element):
-    """Separates two terms within a <term> node.
-
-    .. versionchanged:: 1.4
-       sphinx.addnodes.termsep is deprecated. It will be removed at Sphinx-1.6.
-    """
-
-    def __init__(self, *args, **kw):
-        warnings.warn('sphinx.addnodes.termsep will be removed at Sphinx-1.6',
-                      RemovedInSphinx16Warning, stacklevel=2)
-        super(termsep, self).__init__(*args, **kw)
-
-
-class manpage(nodes.Inline, nodes.TextElement):
+class manpage(nodes.Inline, nodes.FixedTextElement):
     """Node for references to manpages."""
 
 
