@@ -5,7 +5,7 @@
 
     Handlers for additional ReST directives.
 
-    :copyright: Copyright 2007-2016 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -29,6 +29,12 @@ from sphinx.directives.patches import (  # noqa
     Figure, Meta
 )
 
+if False:
+    # For type annotation
+    from typing import Any, Dict, List  # NOQA
+    from sphinx.application import Sphinx  # NOQA
+    from sphinx.environment import BuildEnvironment  # NOQA
+
 
 # RE to strip backslash escapes
 nl_escape_re = re.compile(r'\\\n')
@@ -51,9 +57,13 @@ class ObjectDescription(Directive):
     }
 
     # types of doc fields that this directive handles, see sphinx.util.docfields
-    doc_field_types = []
+    doc_field_types = []    # type: List[Any]
+    domain = None           # type: unicode
+    objtype = None          # type: unicode
+    indexnode = None        # type: addnodes.index
 
     def get_signatures(self):
+        # type: () -> List[unicode]
         """
         Retrieve the signatures to document from the directive arguments.  By
         default, signatures are given as arguments, one per line.
@@ -65,6 +75,7 @@ class ObjectDescription(Directive):
         return [strip_backslash_re.sub(r'\1', line.strip()) for line in lines]
 
     def handle_signature(self, sig, signode):
+        # type: (unicode, addnodes.desc_signature) -> Any
         """
         Parse the signature *sig* into individual nodes and append them to
         *signode*. If ValueError is raised, parsing is aborted and the whole
@@ -77,6 +88,7 @@ class ObjectDescription(Directive):
         raise ValueError
 
     def add_target_and_index(self, name, sig, signode):
+        # type: (Any, unicode, addnodes.desc_signature) -> None
         """
         Add cross-reference IDs and entries to self.indexnode, if applicable.
 
@@ -85,6 +97,7 @@ class ObjectDescription(Directive):
         return  # do nothing by default
 
     def before_content(self):
+        # type: () -> None
         """
         Called before parsing content. Used to set information about the current
         directive context on the build environment.
@@ -92,6 +105,7 @@ class ObjectDescription(Directive):
         pass
 
     def after_content(self):
+        # type: () -> None
         """
         Called after parsing content. Used to reset information about the
         current directive context on the build environment.
@@ -99,6 +113,7 @@ class ObjectDescription(Directive):
         pass
 
     def run(self):
+        # type: () -> List[nodes.Node]
         """
         Main directive entry function, called by docutils upon encountering the
         directive.
@@ -120,7 +135,7 @@ class ObjectDescription(Directive):
             self.domain, self.objtype = self.name.split(':', 1)
         else:
             self.domain, self.objtype = '', self.name
-        self.env = self.state.document.settings.env
+        self.env = self.state.document.settings.env  # type: BuildEnvironment
         self.indexnode = addnodes.index(entries=[])
 
         node = addnodes.desc()
@@ -130,7 +145,7 @@ class ObjectDescription(Directive):
         node['objtype'] = node['desctype'] = self.objtype
         node['noindex'] = noindex = ('noindex' in self.options)
 
-        self.names = []
+        self.names = []  # type: List[unicode]
         signatures = self.get_signatures()
         for i, sig in enumerate(signatures):
             # add a signature node for each signature in the current unit
@@ -181,6 +196,7 @@ class DefaultRole(Directive):
     final_argument_whitespace = False
 
     def run(self):
+        # type: () -> List[nodes.Node]
         if not self.arguments:
             if '' in roles._roles:
                 # restore the "default" default role
@@ -209,9 +225,10 @@ class DefaultDomain(Directive):
     required_arguments = 1
     optional_arguments = 0
     final_argument_whitespace = False
-    option_spec = {}
+    option_spec = {}  # type: Dict
 
     def run(self):
+        # type: () -> List[nodes.Node]
         env = self.state.document.settings.env
         domain_name = self.arguments[0].lower()
         # if domain_name not in env.domains:
@@ -225,6 +242,7 @@ class DefaultDomain(Directive):
 
 
 def setup(app):
+    # type: (Sphinx) -> Dict[unicode, Any]
     directives.register_directive('default-role', DefaultRole)
     directives.register_directive('default-domain', DefaultDomain)
     directives.register_directive('describe', ObjectDescription)
