@@ -18,6 +18,7 @@ import codecs
 import fnmatch
 import warnings
 from os import path
+from copy import copy
 from collections import defaultdict
 
 from six import BytesIO, itervalues, class_types, next
@@ -44,7 +45,7 @@ from sphinx.util.matching import compile_matchers
 from sphinx.util.parallel import ParallelTasks, parallel_available, make_chunks
 from sphinx.util.websupport import is_commentable
 from sphinx.errors import SphinxError, ExtensionError
-from sphinx.locale import _
+from sphinx.locale import __
 from sphinx.transforms import SphinxTransformer
 from sphinx.versioning import add_uids, merge_doctrees
 from sphinx.deprecation import RemovedInSphinx17Warning, RemovedInSphinx20Warning
@@ -300,8 +301,7 @@ class BuildEnvironment(object):
         be emitted instantly, but collected for emitting all warnings after
         the update of the environment.
         """
-        # strange argument order is due to backwards compatibility
-        self._warnfunc(msg, (docname, lineno), **kwargs)
+        self.app.warn(msg, location=(docname, lineno), **kwargs)  # type: ignore
 
     def warn_node(self, msg, node, **kwargs):
         # type: (unicode, nodes.Node, Any) -> None
@@ -566,10 +566,10 @@ class BuildEnvironment(object):
         if parallel_available and len(docnames) > 5 and self.app.parallel > 1:
             for ext in itervalues(self.app.extensions):
                 if ext.parallel_read_safe is None:
-                    logger.warning(_('the %s extension does not declare if it is safe '
-                                     'for parallel reading, assuming it isn\'t - please '
-                                     'ask the extension author to check and make it '
-                                     'explicit'), ext.name)
+                    logger.warning(__('the %s extension does not declare if it is safe '
+                                      'for parallel reading, assuming it isn\'t - please '
+                                      'ask the extension author to check and make it '
+                                      'explicit'), ext.name)
                     logger.warning('doing serial read')
                     break
                 elif ext.parallel_read_safe is False:
@@ -665,6 +665,7 @@ class BuildEnvironment(object):
 
         self.temp_data['docname'] = docname
         # defaults to the global default, but can be re-set in a document
+        self.temp_data['default_role'] = self.config.default_role
         self.temp_data['default_domain'] = \
             self.domains.get(self.config.primary_domain)
 
@@ -675,19 +676,20 @@ class BuildEnvironment(object):
 
         language = self.config.language or 'en'
         self.settings['language_code'] = language
-        self.settings['smart_quotes'] = True
-        if self.config.html_use_smartypants is not None:
-            warnings.warn("html_use_smartypants option is deprecated. Smart "
-                          "quotes are on by default; if you want to disable "
-                          "or customize them, use the smart_quotes option in "
-                          "docutils.conf.",
-                          RemovedInSphinx17Warning)
-            self.settings['smart_quotes'] = self.config.html_use_smartypants
-        for tag in normalize_language_tag(language):
-            if tag in smartchars.quotes:
-                break
-        else:
-            self.settings['smart_quotes'] = False
+        if 'smart_quotes' not in self.settings:
+            self.settings['smart_quotes'] = True
+            if self.config.html_use_smartypants is not None:
+                warnings.warn("html_use_smartypants option is deprecated. Smart "
+                              "quotes are on by default; if you want to disable "
+                              "or customize them, use the smart_quotes option in "
+                              "docutils.conf.",
+                              RemovedInSphinx17Warning)
+                self.settings['smart_quotes'] = self.config.html_use_smartypants
+            for tag in normalize_language_tag(language):
+                if tag in smartchars.quotes:
+                    break
+            else:
+                self.settings['smart_quotes'] = False
 
         docutilsconf = path.join(self.srcdir, 'docutils.conf')
         # read docutils.conf from source dir, not from current dir
@@ -947,6 +949,7 @@ class BuildEnvironment(object):
         """Apply all post-transforms."""
         try:
             # set env.docname during applying post-transforms
+            backup = copy(self.temp_data)
             self.temp_data['docname'] = docname
 
             transformer = SphinxTransformer(doctree)
@@ -954,7 +957,7 @@ class BuildEnvironment(object):
             transformer.add_transforms(self.app.post_transforms)
             transformer.apply_transforms()
         finally:
-            self.temp_data.clear()
+            self.temp_data = backup
 
         # allow custom references to be resolved
         self.app.emit('doctree-resolved', doctree, docname)
